.. _main:

#######
Stylish
#######

Style transfer using deep neural network.

.. toctree::
    :maxdepth: 1

    introduction
    installing
    tutorial
    command_line
    api_reference/index
    release/index
    glossary

******************
Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
